#
# spec file for package python-PyJWT
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-PyJWT
Version:        1.4.2
Release:        1.1
Url:            https://github.com/progrium/pyjwt
Summary:        JSON Web Token implementation in Python
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/P/PyJWT/PyJWT-%{version}.tar.gz
# PATCH-FIX-CENTOS PyJWT-1.1.0.diff -- without this, the centos build %%check will try to download stuff from pypi --seife
Patch1:         PyJWT-1.1.0.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-cryptography
BuildRequires:  python-devel
BuildRequires:  python-ecdsa
BuildRequires:  python-pycrypto
BuildRequires:  python-pytest
BuildRequires:  python-pytest-cov >= 1.7
BuildRequires:  python-pytest-runner
BuildRequires:  python-setuptools
Requires:       python-cryptography
Requires:       python-ecdsa
Requires:       python-pycrypto
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A Python implementation of JSON Web Token draft 01.

%prep
%setup -q -n PyJWT-%{version}
%if 0%{?rhel}
%patch1 -p1
%endif

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
PYTHONPATH=%{buildroot}%{python_sitelib} py.test -k "not test_verify_false_deprecated"

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGELOG.md LICENSE README.md
%{python_sitelib}/*
%{_bindir}/jwt

%changelog
* Thu Sep 15 2016 rjschwei@suse.com
- Include in SLES 12 (FATE#321371, bsc#998103)
* Thu Sep  1 2016 tbechtold@suse.com
- Use https for Source url
* Thu Sep  1 2016 tbechtold@suse.com
- update to 1.4.2:
  - A PEM-formatted key encoded as bytes could cause a `TypeError` to be raised [#213][213]
  - Newer versions of Pytest could not detect warnings properly [#182][182]
  - Non-string 'kid' value now raises `InvalidTokenError` [#174][174]
  - `jwt.decode(None)` now gracefully fails with `InvalidTokenError` [#183][183]
* Tue Jan  5 2016 bwiedemann@suse.com
- BuildRequire python-pytest-cov >= 1.7
* Thu Nov  5 2015 toddrme2178@gmail.com
- Update to 1.4.0
  + Fixed
  * Exclude Python cache files from PyPI releases.
  + Added
  * Added new options to require certain claims
    (require_nbf, require_iat, require_exp) and raise `MissingRequiredClaimError`
    if they are not present.
  * If `audience=` or `issuer=` is specified but the claim is not present,
    `MissingRequiredClaimError` is now raised instead of `InvalidAudienceError`
    and `InvalidIssuerError`
- Update to 1.3.0
  + Fixed
  * ECDSA (ES256, ES384, ES512) signatures are now being properly serialized [#158][158]
  * RSA-PSS (PS256, PS384, PS512) signatures now use the proper salt length for PSS padding. [#163][163]
  + Added
  * Added a new `jwt.get_unverified_header()` to parse and return the header portion of a token prior to signature verification.
  + Removed
  * Python 3.2 is no longer a supported platform. This version of Python is
    rarely used. Users affected by this should upgrade to 3.3+.
- Update to 1.2.0
  + Fixed
  * Added back `verify_expiration=` argument to `jwt.decode()` that was erroneously removed in [v1.1.0][1.1.0].
  + Changed
  * Refactored JWS-specific logic out of PyJWT and into PyJWS superclass. [#141][141]
  + Deprecated
  * `verify_expiration=` argument to `jwt.decode()` is now deprecated and will be removed in a future version. Use the `option=` argument instead.
- Rebase PyJWT-1.1.0.diff
* Mon Aug 10 2015 seife+obs@b1-systems.com
- apply PyJWT-1.1.0.diff only on RHEL/CentOS
* Thu Jul  9 2015 seife+obs@b1-systems.com
- fix build on RHEL7, add PyJWT-1.1.0.diff
* Wed Apr 22 2015 mcihar@suse.cz
- Include pycrypto and ecdsa in BuildRequires for complete test coverage
- Use setup.py test to execute testsuite
* Wed Apr 22 2015 mcihar@suse.cz
- Simplify dependencies (only python-cryptography is needed, pycrypto and ecdsa
  are just fallbacks whet is is not)
* Mon Apr 20 2015 mcihar@suse.cz
- Enable testsuite during build
* Mon Apr 20 2015 mcihar@suse.cz
- Update to 1.1.0
* Thu Nov  6 2014 mcihar@suse.cz
- Update to 0.3.0
* Wed Jul 23 2014 mcihar@suse.cz
- initial packaging
